from . import tools
from agentsjson.core.models.tools import ExecutorType

# Define the type of execution (REST API, Function call, etc.)
map_type = ExecutorType.RESTAPIHANDLER

# Mapping of operation IDs to corresponding function implementations
map = {
    # Calendar Operations
    "google_calendar_calendars_insert": tools.create_calendar,
    "google_calendar_calendars_delete": tools.delete_calendar,
    "google_calendar_calendars_get": tools.get_calendar_details,
    "google_calendar_calendars_list": tools.list_calendars,
    "google_calendar_calendars_update": tools.update_calendar_settings,

    # Event Operations
    "google_calendar_events_insert": tools.create_event,
    "google_calendar_events_delete": tools.delete_event,
    "google_calendar_events_patch": tools.update_event,
    "google_calendar_events_get": tools.get_event_details,
    "google_calendar_events_list": tools.list_events,

    # Attendee Management
    "google_calendar_events_attendees_add": tools.add_attendee,
    "google_calendar_events_attendees_remove": tools.remove_attendee,
    "google_calendar_events_attendees_update": tools.update_attendee_response,

    # Permissions & ACL
    "google_calendar_acl_insert": tools.set_calendar_permissions,
    "google_calendar_acl_list": tools.list_calendar_access_control,
    "google_calendar_acl_delete": tools.remove_user_access,

    # Availability & Scheduling
    "google_calendar_freebusy_query": tools.check_free_busy,
    "google_calendar_working_hours_set": tools.set_working_hours,
    "google_calendar_events_reschedule": tools.reschedule_event,

    # Notifications & Reminders
    "google_calendar_events_reminders_set": tools.set_event_reminder,
    "google_calendar_notifications_subscribe": tools.subscribe_calendar_updates,
    "google_calendar_notifications_unsubscribe": tools.unsubscribe_calendar_updates,

    # AI-Powered Features
    "google_calendar_ai_generate_agenda": tools.auto_generate_agenda,
    "google_calendar_ai_categorize_event": tools.smart_event_categorization,
    "google_calendar_ai_predict_meeting_time": tools.predict_best_meeting_time,

    # Data Import/Export
    "google_calendar_events_import": tools.import_events,
    "google_calendar_calendars_export": tools.export_calendar,
    "google_calendar_events_migrate": tools.migrate_events,

    # Bulk Operations
    "google_calendar_events_bulk_delete": tools.bulk_delete_events,
    "google_calendar_events_bulk_update": tools.bulk_update_events,

    # Advanced Analytics
    "google_calendar_events_summary_report": tools.generate_event_summary,
    "google_calendar_meeting_attendance_track": tools.track_meeting_attendance,
    "google_calendar_events_trends_analysis": tools.analyze_event_trends,
}
